#ifndef WINLIST_H
#define WINLIST_H

#include "obj.h"
#include "win.h"


/* Scan List */
extern gint WinScanListInsert(
	win_struct *win, gint row,
	obj_struct *obj			/* Transfered */
);
extern gint WinScanListAppend(
	win_struct *win,
	obj_struct *obj			/* Transfered */
);
extern void WinScanListRemove(win_struct *win, gint row);
extern void WinScanListClear(win_struct *win);
extern void WinScanListUpdateRow(
	win_struct *win, gint row, const obj_struct *obj
);
extern void WinScanListTouchByLocation(
        win_struct *win,
        const gchar *location,
        const gulong t
);

/* Results List */
extern gint WinResultsListAppend(
	win_struct *win,
	const gchar *path, const gchar *virus_name,
	const gboolean infected
);
extern void WinResultsListClear(win_struct *win);


#endif	/* WINLIST_H */
